==> deepin-camera_1.0.0.15.orig.tar.xz: deepin-camera-1.0.0.15/src/translations/deepin-camera_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video kaydı devam ediyor. Pencere kapatılsın mı?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Klasör aç</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Klasör aç</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Bu klasörü kullanma izniniz yok</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation>Geçersiz klasör</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Klasör aç</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Temel</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Dosya konumu</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Çekim</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Seri çekim kipi</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Zamanlayıcı gecikmesi</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Çıktı</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Çıktı biçimi</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 adet</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 adet</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera, PC kameranızı veya web kameranızı kullanan bir görüntü ve video yakalama aracıdır.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Dosya kaydedilemedi</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation>Şuraya kaydet:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotoğraf:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Çözünürlük ayarları</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Çözünürlük:</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation>Fotoğraf çek</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>Video kaydet</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Fotoğraf çekmeyi bırak</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Web kamerası bulunamadı</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Web kamerası kullanımda</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Kaydı durdur</translation>
    </message>
</context>
</TS>

==> deepin-camera_1.3.10.orig.tar.xz: deepin-camera-1.3.10/src/translations/deepin-camera_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>Video kaydı devam ediyor. Pencere kapatılsın mı?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">Klasör aç</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>Fotoğraf</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>Kameraları Değiştir</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Klasör aç</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Yazdır</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>Bu klasörü kullanma izniniz yok</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">Geçersiz klasör</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>Klasör aç</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Temel</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>Dosya konumu</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>Çekim</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>Seri çekim kipi</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>Zamanlayıcı gecikmesi</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Çıktı</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>Çıktı biçimi</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 adet</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 adet</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>Kamera, PC kameranızı veya web kameranızı kullanan bir görüntü ve video yakalama aracıdır.</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>Dosya kaydedilemedi</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">Şuraya kaydet:</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>Fotoğraf:</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>Video:</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>Çözünürlük ayarları</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation>Çözünürlük:</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>Fotoğraflar:</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>Videolar:</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>Ses efektleri</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>Ayna kipi</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>El feneri</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>Kaydı durdur</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Kopyala</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Yazdır</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Kısayolları göster</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>Fotoğraf çekmeyi bırak</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>Bağlam menüsü</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">Fotoğraf çek</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">Video kaydet</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">Fotoğraf çekmeyi bırak</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation>Canlı</translation>
    </message>
    <message>
        <source>Warm</source>
        <translation>Ilık</translation>
    </message>
    <message>
        <source>Cold</source>
        <translation>Soğuk</translation>
    </message>
    <message>
        <source>Retro</source>
        <translation>Retro</translation>
    </message>
    <message>
        <source>Film</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>Gri</translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation>B&amp;W</translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>El feneri</translation>
    </message>
    <message>
        <source>On</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>Gecikmeli yakalama</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Yok</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation>Filtreler</translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation>Teşhir</translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>Web kamerası bulunamadı</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>Web kamerası kullanımda</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">Kaydı durdur</translation>
    </message>
</context>
</TS>
